@@ -1,21 +1,7 @@
 
 const base = {};
 
-base.Complex64 = class Complex64 {
-
-    constructor(real, imaginary) {
-        this.real = real;
-        this.imaginary = imaginary;
-    }
-
-    toString(/* radix */) {
-        const sign = this.imaginary < 0 ? '-' : '+';
-        const imaginary = Math.abs(this.imaginary);
-        return `${this.real} ${sign} ${imaginary}i`;
-    }
-};
-
-base.Complex128 = class Complex128 {
+base.Complex = class Complex {
 
     constructor(real, imaginary) {
         this.real = real;
@@ -210,6 +196,53 @@ if (!DataView.prototype.getFloat8e5m2) {
     };
 }
 
+if (!DataView.prototype.getFloat8e3m4) {
+    DataView.__float8e3m4_float32 = new Float32Array(1);
+    DataView.__float8e3m4_uint32 = new Uint32Array(DataView.__float8e3m4_float32.buffer, DataView.__float8e3m4_float32.byteOffset, 1);
+    DataView.prototype.getFloat8e3m4 = function(byteOffset) {
+        const value = this.getUint8(byteOffset);
+        const exponent_bias = 3;
+        if (value === 0x7f) {
+            return NaN;
+        }
+        if (value === 0xff) {
+            return -NaN;
+        }
+        let expo = (value & 0x70) >> 4;
+        let mant = value & 0x0F;
+        const sign = value & 0x80;
+        let res = sign << 24;
+        if (expo === 0) {
+            if (mant > 0) {
+                expo = 0x7F - exponent_bias;
+                if ((mant & 0x8) === 0) {
+                    mant &= 0x7;
+                    mant <<= 1;
+                    expo -= 1;
+                }
+                if ((mant & 0x8) === 0) {
+                    mant &= 0x7;
+                    mant <<= 1;
+                    expo -= 1;
+                }
+                if ((mant & 0x8) === 0) {
+                    mant &= 0x7;
+                    mant <<= 1;
+                    expo -= 1;
+                }
+                res |= (mant & 0x7) << 20;
+                res |= expo << 23;
+            }
+        } else {
+            res |= mant << 19;
+            expo += 0x7F - exponent_bias;
+            res |= expo << 23;
+        }
+        DataView.__float8e3m4_uint32[0] = res;
+        return DataView.__float8e3m4_float32[0];
+    };
+}
+
 DataView.prototype.getIntBits = DataView.prototype.getUintBits || function(offset, bits, littleEndian) {
     offset *= bits;
     const position = Math.floor(offset / 8);
@@ -240,13 +273,25 @@ DataView.prototype.getUintBits = DataView.prototype.getUintBits || function(offs
     return value & ((1 << bits) - 1);
 };
 
-DataView.prototype.getComplex64 = DataView.prototype.getComplex64 || function(byteOffset, littleEndian) {
-    const real = littleEndian ? this.getFloat32(byteOffset, littleEndian) : this.getFloat32(byteOffset + 4, littleEndian);
-    const imaginary = littleEndian ? this.getFloat32(byteOffset + 4, littleEndian) : this.getFloat32(byteOffset, littleEndian);
-    return new base.Complex64(real, imaginary);
+DataView.prototype.getComplexInt32 = DataView.prototype.getComplexInt32 || function(byteOffset, littleEndian) {
+    const real = littleEndian ? this.getInt32(byteOffset, littleEndian) : this.getInt32(byteOffset + 4, littleEndian);
+    const imaginary = littleEndian ? this.getInt32(byteOffset + 4, littleEndian) : this.getInt32(byteOffset, littleEndian);
+    return new base.Complex(real, imaginary);
 };
 
-DataView.prototype.setComplex64 = DataView.prototype.setComplex64 || function(byteOffset, value, littleEndian) {
+DataView.prototype.getComplexFloat16 = DataView.prototype.getComplexFloat16 || function(byteOffset, littleEndian) {
+    const real = littleEndian ? this.getFloat16(byteOffset, littleEndian) : this.getFloat16(byteOffset + 4, littleEndian);
+    const imaginary = littleEndian ? this.getFloat16(byteOffset + 4, littleEndian) : this.getFloat16(byteOffset, littleEndian);
+    return new base.Complex(real, imaginary);
+};
+
+DataView.prototype.getComplexFloat32 = DataView.prototype.getComplexFloat32 || function(byteOffset, littleEndian) {
+    const real = littleEndian ? this.getFloat32(byteOffset, littleEndian) : this.getFloat32(byteOffset + 4, littleEndian);
+    const imaginary = littleEndian ? this.getFloat32(byteOffset + 4, littleEndian) : this.getFloat32(byteOffset, littleEndian);
+    return new base.Complex(real, imaginary);
+};
+
+DataView.prototype.setComplexFloat32 = DataView.prototype.setComplexFloat32 || function(byteOffset, value, littleEndian) {
     if (littleEndian) {
         this.setFloat32(byteOffset, value.real, littleEndian);
         this.setFloat32(byteOffset + 4, value.imaginary, littleEndian);
@@ -256,13 +301,13 @@ DataView.prototype.setComplex64 = DataView.prototype.setComplex64 || function(by
     }
 };
 
-DataView.prototype.getComplex128 = DataView.prototype.getComplex128 || function(byteOffset, littleEndian) {
+DataView.prototype.getComplexFloat64 = DataView.prototype.getComplexFloat64 || function(byteOffset, littleEndian) {
     const real = littleEndian ? this.getFloat64(byteOffset, littleEndian) : this.getFloat64(byteOffset + 8, littleEndian);
     const imaginary = littleEndian ? this.getFloat64(byteOffset + 8, littleEndian) : this.getFloat64(byteOffset, littleEndian);
-    return new base.Complex128(real, imaginary);
+    return new base.Complex(real, imaginary);
 };
 
-DataView.prototype.setComplex128 = DataView.prototype.setComplex128 || function(byteOffset, value, littleEndian) {
+DataView.prototype.setComplexFloat64 = DataView.prototype.setComplexFloat64 || function(byteOffset, value, littleEndian) {
     if (littleEndian) {
         this.setFloat64(byteOffset, value.real, littleEndian);
         this.setFloat64(byteOffset + 8, value.imaginary, littleEndian);
@@ -614,8 +659,8 @@ base.Tensor = class {
             ['int8', 1], ['int16', 2], ['int32', 4], ['int64', 8],
             ['uint8', 1], ['uint16', 2], ['uint32', 4,], ['uint64', 8],
             ['float16', 2], ['float32', 4], ['float64', 8], ['bfloat16', 2],
-            ['complex64', 8], ['complex128', 16],
-            ['float8e4m3fn', 1], ['float8e4m3fnuz', 1], ['float8e5m2', 1], ['float8e5m2fnuz', 1]
+            ['complex<float32>', 8], ['complex<float64>', 16], ['complex<int32>', 8],
+            ['float8e4m3fn', 1], ['float8e4m3fnuz', 1], ['float8e5m2', 1], ['float8e5m2fnuz', 1], ['float8e3m4', 1], ['float8e4m3', 1],
         ]);
     }
 
@@ -789,7 +834,8 @@ base.Tensor = class {
                     }
                     case '|': {
                         context.data = this.values;
-                        if (!base.Tensor._dataTypes.has(dataType) && dataType !== 'string' && dataType !== 'object' && dataType !== 'datetime' && dataType !== 'void') {
+                        const integer = (dataType.startsWith('int') && !isNaN(parseInt(dataType.substring(3), 10))) || (dataType.startsWith('uint') && !isNaN(parseInt(dataType.substring(4), 10)));
+                        if (!base.Tensor._dataTypes.has(dataType) && dataType !== 'string' && dataType !== 'object' && dataType !== 'datetime' && dataType !== 'void' && !integer) {
                             throw new Error(`Tensor data type '${dataType}' is not implemented.`);
                         }
                         const size = context.dimensions.reduce((a, v) => a * v, 1);
@@ -929,14 +975,24 @@ base.Tensor = class {
                         results.push(view.getBfloat16(offset, this._littleEndian));
                     }
                     break;
-                case 'complex64':
+                case 'complex<int32>':
                     for (; offset < max; offset += stride) {
-                        results.push(view.getComplex64(offset, this._littleEndian));
+                        results.push(view.getComplexInt32(offset, this._littleEndian));
                     }
                     break;
-                case 'complex128':
+                case 'complex<float16>':
                     for (; offset < max; offset += stride) {
-                        results.push(view.getComplex128(offset, this._littleEndian));
+                        results.push(view.getComplexFloat16(offset, this._littleEndian));
+                    }
+                    break;
+                case 'complex<float32>':
+                    for (; offset < max; offset += stride) {
+                        results.push(view.getComplexFloat32(offset, this._littleEndian));
+                    }
+                    break;
+                case 'complex<float64>':
+                    for (; offset < max; offset += stride) {
+                        results.push(view.getComplexFloat64(offset, this._littleEndian));
                     }
                     break;
                 case 'float4e2m1':
@@ -944,6 +1000,11 @@ base.Tensor = class {
                         results.push(view.getFloat4e2m1(offset));
                     }
                     break;
+                case 'float8e3m4':
+                    for (; offset < max; offset += stride) {
+                        results.push(view.getFloat8e3m4(offset));
+                    }
+                    break;
                 case 'float8e4m3fn':
                     for (; offset < max; offset += stride) {
                         results.push(view.getFloat8e4m3(offset, true, false));
@@ -1267,7 +1328,7 @@ base.Metadata = class {
             'gguf',
             'hd5', 'hdf5', 'keras',
             'tfl', 'circle', 'lite',
-            'mlir', 'mlnet', 'mar', 'maxviz', 'meta', 'nn', 'ngf', 'hn',
+            'mlir', 'mlirbc', 'mlnet', 'mar', 'maxviz', 'meta', 'nn', 'ngf', 'hn',
             'param', 'params',
             'paddle', 'pdiparams', 'pdmodel', 'pdopt', 'pdparams', 'nb',
             'pkl', 'pickle', 'joblib', 'safetensors',
@@ -1279,8 +1340,7 @@ base.Metadata = class {
     }
 };
 
-export const Complex64 = base.Complex64;
-export const Complex128 = base.Complex128;
+export const Complex = base.Complex;
 export const BinaryStream = base.BinaryStream;
 export const BinaryReader = base.BinaryReader;
 export const Tensor = base.Tensor;
