@@ -496,7 +496,7 @@ om.Utility = class {
         om.Utility._types = om.Utility._types || [
             'undefined', 'float32', 'float16', 'int8', 'uint8', 'int16', 'uint16', 'int32',
             'int64', 'uint32', 'uint64', 'boolean', 'float64', 'string', 'dual_sub_int8', 'dual_sub_uint8',
-            'complex64', 'complex128', 'qint8', 'qint16', 'qint32', 'quint8', 'quint16', 'resource',
+            'complex<float32>', 'complex<float64>', 'qint8', 'qint16', 'qint32', 'quint8', 'quint16', 'resource',
             'stringref', 'dual', 'variant', 'bfloat16', 'int4', 'uint1', 'int2', 'uint2'
         ];
         if (value >= om.Utility._types.length) {
